# SchemaDefinition


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**count_of_uniqueu_vertex_and_edge_objects_created** | **int** |  | [optional] 
**count_of_vertex_and_edges_registered_with_device_data_manager** | **int** |  | [optional] 
**vertex_definitions_for_data_collection** | **[str]** |  | [optional] 
**vertex_definitions_found_in_db_with_data** | [**[VertexDefinition]**](VertexDefinition.md) |  | [optional] 
**vertex_definitions_found_in_db_without_data** | **[str]** |  | [optional] 
**vertex_definitions_not_found_in_db** | **[str]** |  | [optional] 
**vertex_definitions_not_registered_with_device_data_manager** | **[str]** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


